@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 '''
-Copyright (C) 2019, WAFW00F Developers.
+Copyright (C) 2022, WAFW00F Developers.
 See the LICENSE file for copying permission.
 '''
+# For keeping python2 support for now
+from __future__ import print_function
+
 import csv
 import io
 import json
@@ -20,6 +23,7 @@ from wafw00f.manager import load_plugins
 from wafw00f.wafprio import wafdetectionsprio
 from wafw00f.lib.evillib import urlParser, waftoolsengine, def_headers
 
+
 class WAFW00F(waftoolsengine):
 
     xsstring = '<script>alert("XSS");</script>'
@@ -35,6 +39,7 @@ class WAFW00F(waftoolsengine):
         self.attackres = None
         waftoolsengine.__init__(self, target, debuglevel, path, proxies, followredirect, extraheaders)
         self.knowledge = dict(generic=dict(found=False, reason=''), wafname=list())
+        self.rq = self.normalRequest()
 
     def normalRequest(self):
         return self.Request()
@@ -85,17 +90,18 @@ class WAFW00F(waftoolsengine):
             # Testing for no user-agent response. Detects almost all WAFs out there.
             resp1 = self.performCheck(self.normalRequest)
             if 'User-Agent' in self.headers:
-                del self.headers['User-Agent']  # Deleting the user-agent key from object not dict.
-            resp3 = self.customRequest(headers=def_headers)
-            if resp1.status_code != resp3.status_code:
-                self.log.info('Server returned a different response when request didn\'t contain the User-Agent header.')
-                reason = reasons[4]
-                reason += '\r\n'
-                reason += 'Normal response code is "%s",' % resp1.status_code
-                reason += ' while the response code to a modified request is "%s"' % resp3.status_code
-                self.knowledge['generic']['reason'] = reason
-                self.knowledge['generic']['found'] = True
-                return True
+                self.headers.pop('User-Agent')  # Deleting the user-agent key from object not dict.
+            resp3 = self.customRequest(headers=self.headers)
+            if resp3 is not None and resp1 is not None:
+                if resp1.status_code != resp3.status_code:
+                    self.log.info('Server returned a different response when request didn\'t contain the User-Agent header.')
+                    reason = reasons[4]
+                    reason += '\r\n'
+                    reason += 'Normal response code is "%s",' % resp1.status_code
+                    reason += ' while the response code to a modified request is "%s"' % resp3.status_code
+                    self.knowledge['generic']['reason'] = reason
+                    self.knowledge['generic']['found'] = True
+                    return True
 
             # Testing the status code upon sending a xss attack
             resp2 = self.performCheck(self.xssAttack)
@@ -134,20 +140,22 @@ class WAFW00F(waftoolsengine):
                 return True
 
             # Checking for the Server header after sending malicious requests
+            normalserver, attackresponse_server = '', ''
             response = self.attackres
-            normalserver = resp1.headers.get('Server')
-            attackresponse_server = response.headers.get('Server')
-            if attackresponse_server:
-                if attackresponse_server != normalserver:
-                    self.log.info('Server header changed, WAF possibly detected')
-                    self.log.debug('Attack response: %s' % attackresponse_server)
-                    self.log.debug('Normal response: %s' % normalserver)
-                    reason = reasons[1]
-                    reason += '\r\nThe server header for a normal response is "%s",' % normalserver
-                    reason += ' while the server header a response to an attack is "%s",' % attackresponse_server
-                    self.knowledge['generic']['reason'] = reason
-                    self.knowledge['generic']['found'] = True
-                    return True
+            if 'server' in resp1.headers:
+                normalserver = resp1.headers.get('Server')
+            if response is not None and 'server' in response.headers:
+                attackresponse_server = response.headers.get('Server')
+            if attackresponse_server != normalserver:
+                self.log.info('Server header changed, WAF possibly detected')
+                self.log.debug('Attack response: %s' % attackresponse_server)
+                self.log.debug('Normal response: %s' % normalserver)
+                reason = reasons[1]
+                reason += '\r\nThe server header for a normal response is "%s",' % normalserver
+                reason += ' while the server header a response to an attack is "%s",' % attackresponse_server
+                self.knowledge['generic']['reason'] = reason
+                self.knowledge['generic']['found'] = True
+                return True
 
         # If at all request doesn't go, press F
         except RequestBlocked:
@@ -159,9 +167,11 @@ class WAFW00F(waftoolsengine):
     def matchHeader(self, headermatch, attack=False):
         if attack:
             r = self.attackres
-        else: r = rq
+        else:
+            r = self.rq
         if r is None:
             return
+
         header, match = headermatch
         headerval = r.headers.get(header)
         if headerval:
@@ -179,7 +189,8 @@ class WAFW00F(waftoolsengine):
     def matchStatus(self, statuscode, attack=True):
         if attack:
             r = self.attackres
-        else: r = rq
+        else:
+            r = self.rq
         if r is None:
             return
         if r.status_code == statuscode:
@@ -192,7 +203,8 @@ class WAFW00F(waftoolsengine):
     def matchReason(self, reasoncode, attack=True):
         if attack:
             r = self.attackres
-        else: r = rq
+        else:
+            r = self.rq
         if r is None:
             return
         # We may need to match multiline context in response body
@@ -203,7 +215,8 @@ class WAFW00F(waftoolsengine):
     def matchContent(self, regex, attack=True):
         if attack:
             r = self.attackres
-        else: r = rq
+        else:
+            r = self.rq
         if r is None:
             return
         # We may need to match multiline context in response body
@@ -270,7 +283,7 @@ def getTextResults(res=None):
         p = [str(x) for _, x in dk.items()]
         rows.append(p)
     for m in rows:
-        m[1] = f'{m[1]} ({m[2]})'
+        m[1] = '%s (%s)' % (m[1], m[2])
         m.pop()
     defgen = [
         (max([len(str(row[i])) for row in rows]) + 3)
@@ -315,6 +328,8 @@ def main():
     parser.add_option('-t', '--test', dest='test', help='Test for one specific WAF')
     parser.add_option('-o', '--output', dest='output', help='Write output to csv, json or text file depending on file extension. For stdout, specify - as filename.',
                       default=None)
+    parser.add_option('-f', '--format', dest='format', help='Force output format to csv, json or text.',
+                      default=None)
     parser.add_option('-i', '--input-file', dest='input', help='Read targets from a file. Input format can be csv, json or text. For csv and json, a `url` column name or element is required.',
                       default=None)
     parser.add_option('-l', '--list', dest='list', action='store_true',
@@ -333,11 +348,10 @@ def main():
     print(randomArt())
     if options.list:
         print('[+] Can test for these WAFs:\r\n')
-        attacker = WAFW00F(None)
         try:
             m = [i.replace(')', '').split(' (') for i in wafdetectionsprio]
             print(R+'  WAF Name'+' '*24+'Manufacturer\n  '+'-'*8+' '*24+'-'*12+'\n')
-            max_len = max(len(str(x)) for k in m for x in k) 
+            max_len = max(len(str(x)) for k in m for x in k)
             for inner in m:
                 first = True
                 for elem in inner:
@@ -379,7 +393,7 @@ def main():
             elif options.input.endswith('.csv'):
                 columns = defaultdict(list)
                 with open(options.input) as f:
-                    reader = csv.DictReader(f) 
+                    reader = csv.DictReader(f)
                     for row in reader:
                         for (k,v) in row.items():
                             columns[k].append(v)
@@ -402,7 +416,7 @@ def main():
         if pret is None:
             log.critical('The url %s is not well formed' % target)
             sys.exit(1)
-        (hostname, port, path, _, _) = pret
+        (hostname, _, path, _, _) = pret
         log.info('starting wafw00f on %s' % target)
         proxies = dict()
         if options.proxy:
@@ -413,9 +427,7 @@ def main():
         attacker = WAFW00F(target, debuglevel=options.verbose, path=path,
                     followredirect=options.followredirect, extraheaders=extraheaders,
                         proxies=proxies)
-        global rq
-        rq = attacker.normalRequest()
-        if rq is None:
+        if attacker.rq is None:
             log.error('Site %s appears to be down' % hostname)
             continue
         if options.test:
@@ -451,7 +463,20 @@ def main():
     if options.output:
         if options.output == '-':
             enableStdOut()
-            print(os.linesep.join(getTextResults(results)))
+            if options.format == 'json':
+                json.dump(results, sys.stdout, indent=2)
+            elif options.format == 'csv':
+                csvwriter = csv.writer(sys.stdout, delimiter=',', quotechar='"',
+                    quoting=csv.QUOTE_MINIMAL)
+                count = 0
+                for result in results:
+                    if count == 0:
+                        header = result.keys()
+                        csvwriter.writerow(header)
+                        count += 1
+                    csvwriter.writerow(result.values())
+            else:
+                print(os.linesep.join(getTextResults(results)))
         elif options.output.endswith('.json'):
             log.debug("Exporting data in json format to file: %s" % (options.output))
             with open(options.output, 'w') as outfile:
@@ -459,7 +484,7 @@ def main():
         elif options.output.endswith('.csv'):
             log.debug("Exporting data in csv format to file: %s" % (options.output))
             with open(options.output, 'w') as outfile:
-                csvwriter = csv.writer(outfile, delimiter=',', quotechar='"', 
+                csvwriter = csv.writer(outfile, delimiter=',', quotechar='"',
                     quoting=csv.QUOTE_MINIMAL)
                 count = 0
                 for result in results:
@@ -470,8 +495,23 @@ def main():
                     csvwriter.writerow(result.values())
         else:
             log.debug("Exporting data in text format to file: %s" % (options.output))
-            with open(options.output, 'w') as outfile:
-                outfile.write(os.linesep.join(getTextResults(results)))
+            if options.format == 'json':
+                with open(options.output, 'w') as outfile:
+                    json.dump(results, outfile, indent=2)
+            elif options.format == 'csv':
+                with open(options.output, 'w') as outfile:
+                    csvwriter = csv.writer(outfile, delimiter=',', quotechar='"',
+                        quoting=csv.QUOTE_MINIMAL)
+                    count = 0
+                    for result in results:
+                        if count == 0:
+                            header = result.keys()
+                            csvwriter.writerow(header)
+                            count += 1
+                        csvwriter.writerow(result.values())
+            else:
+                with open(options.output, 'w') as outfile:
+                    outfile.write(os.linesep.join(getTextResults(results)))
 
 if __name__ == '__main__':
     if sys.hexversion < 0x2060000:
