@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 '''
-Copyright (C) 2019, WAFW00F Developers.
+Copyright (C) 2022, WAFW00F Developers.
 See the LICENSE file for copying permission.
 '''
 
@@ -50,9 +50,11 @@ wafdetectionsprio = [
     'Cloudfront (Amazon)',
     'CrawlProtect (Jean-Denis Brun)',
     'DataPower (IBM)',
+    'Cloud Protector (Rohde & Schwarz CyberSecurity)',
     'DenyALL (Rohde & Schwarz CyberSecurity)',
     'Distil (Distil Networks)',
     'DOSarrest (DOSarrest Internet Security)',
+    'DDoS-GUARD (DDOS-GUARD CORP.)',
     'DotDefender (Applicure Technologies)',
     'DynamicWeb Injection Check (DynamicWeb)',
     'Edgecast (Verizon Digital Media)',
@@ -104,7 +106,9 @@ wafdetectionsprio = [
     'PowerCDN (PowerCDN)',
     'Profense (ArmorLogic)',
     'Puhui (Puhui)',
+    'Qcloud (Tencent Cloud)',
     'Qiniu (Qiniu CDN)',
+    'Qrator (Qrator)',
     'Reblaze (Reblaze)',
     'RSFirewall (RSJoomla!)',
     'RequestValidationMode (Microsoft)',
@@ -145,6 +149,7 @@ wafdetectionsprio = [
     'WebARX (WebARX Security Solutions)',
     'WebKnight (AQTRONIX)',
     'WebLand (WebLand)',
+    'wpmudev WAF (Incsub)',
     'RayWAF (WebRay Solutions)',
     'WebSEAL (IBM)',
     'WebTotem (WebTotem)',
